==> ngsolve-6.2.2501-cp313-cp313-manylinux_2_28_x86_64.whl: ngsolve-6.2.2501.data/data/lib/cmake/ngsolve/ngsolve-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ngstd" for configuration "Release"
set_property(TARGET ngstd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngstd PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngstd.so"
  IMPORTED_SONAME_RELEASE "libngstd.so"
  )

list(APPEND _cmake_import_check_targets ngstd )
list(APPEND _cmake_import_check_files_for_ngstd "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngstd.so" )

# Import target "ngbla" for configuration "Release"
set_property(TARGET ngbla APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngbla PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngbla.so"
  IMPORTED_SONAME_RELEASE "libngbla.so"
  )

list(APPEND _cmake_import_check_targets ngbla )
list(APPEND _cmake_import_check_files_for_ngbla "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngbla.so" )

# Import target "ngla" for configuration "Release"
set_property(TARGET ngla APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngla PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngla.so"
  IMPORTED_SONAME_RELEASE "libngla.so"
  )

list(APPEND _cmake_import_check_targets ngla )
list(APPEND _cmake_import_check_files_for_ngla "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngla.so" )

# Import target "ngfem" for configuration "Release"
set_property(TARGET ngfem APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngfem PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngfem.so"
  IMPORTED_SONAME_RELEASE "libngfem.so"
  )

list(APPEND _cmake_import_check_targets ngfem )
list(APPEND _cmake_import_check_files_for_ngfem "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngfem.so" )

# Import target "ngcomp" for configuration "Release"
set_property(TARGET ngcomp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngcomp PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngcomp.so"
  IMPORTED_SONAME_RELEASE "libngcomp.so"
  )

list(APPEND _cmake_import_check_targets ngcomp )
list(APPEND _cmake_import_check_files_for_ngcomp "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngcomp.so" )

# Import target "ngsolve" for configuration "Release"
set_property(TARGET ngsolve APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngsolve PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngsolve.so"
  IMPORTED_SONAME_RELEASE "libngsolve.so"
  )

list(APPEND _cmake_import_check_targets ngsolve )
list(APPEND _cmake_import_check_files_for_ngsolve "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngsolve.so" )

# Import target "ngscudalib" for configuration "Release"
set_property(TARGET ngscudalib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngscudalib PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngscudalib.so"
  IMPORTED_SONAME_RELEASE "libngscudalib.so"
  )

list(APPEND _cmake_import_check_targets ngscudalib )
list(APPEND _cmake_import_check_files_for_ngscudalib "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngscudalib.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> ngsolve-6.2.2505.post103.dev0-cp313-cp313-manylinux_2_28_x86_64.whl: ngsolve-6.2.2505.post103.dev0.data/data/lib/cmake/ngsolve/ngsolve-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ngstd" for configuration "Release"
set_property(TARGET ngstd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngstd PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngstd.so"
  IMPORTED_SONAME_RELEASE "libngstd.so"
  )

list(APPEND _cmake_import_check_targets ngstd )
list(APPEND _cmake_import_check_files_for_ngstd "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngstd.so" )

# Import target "ngbla" for configuration "Release"
set_property(TARGET ngbla APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngbla PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngbla.so"
  IMPORTED_SONAME_RELEASE "libngbla.so"
  )

list(APPEND _cmake_import_check_targets ngbla )
list(APPEND _cmake_import_check_files_for_ngbla "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngbla.so" )

# Import target "ngla" for configuration "Release"
set_property(TARGET ngla APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngla PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngla.so"
  IMPORTED_SONAME_RELEASE "libngla.so"
  )

list(APPEND _cmake_import_check_targets ngla )
list(APPEND _cmake_import_check_files_for_ngla "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngla.so" )

# Import target "ngfem" for configuration "Release"
set_property(TARGET ngfem APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngfem PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngfem.so"
  IMPORTED_SONAME_RELEASE "libngfem.so"
  )

list(APPEND _cmake_import_check_targets ngfem )
list(APPEND _cmake_import_check_files_for_ngfem "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngfem.so" )

# Import target "ngsbem" for configuration "Release"
set_property(TARGET ngsbem APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngsbem PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngsbem.so"
  IMPORTED_SONAME_RELEASE "libngsbem.so"
  )

list(APPEND _cmake_import_check_targets ngsbem )
list(APPEND _cmake_import_check_files_for_ngsbem "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngsbem.so" )

# Import target "ngcomp" for configuration "Release"
set_property(TARGET ngcomp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngcomp PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngcomp.so"
  IMPORTED_SONAME_RELEASE "libngcomp.so"
  )

list(APPEND _cmake_import_check_targets ngcomp )
list(APPEND _cmake_import_check_files_for_ngcomp "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngcomp.so" )

# Import target "ngsolve" for configuration "Release"
set_property(TARGET ngsolve APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngsolve PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngsolve.so"
  IMPORTED_SONAME_RELEASE "libngsolve.so"
  )

list(APPEND _cmake_import_check_targets ngsolve )
list(APPEND _cmake_import_check_files_for_ngsolve "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngsolve.so" )

# Import target "ngscudalib" for configuration "Release"
set_property(TARGET ngscudalib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ngscudalib PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngscudalib.so"
  IMPORTED_SONAME_RELEASE "libngscudalib.so"
  )

list(APPEND _cmake_import_check_targets ngscudalib )
list(APPEND _cmake_import_check_files_for_ngscudalib "${_IMPORT_PREFIX}/lib/python3.13/site-packages/netgen_mesher.libs/libngscudalib.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
